cmd

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 28, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Overview

Package cmd wires the cobra command tree for mp2rss CLI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute runs the root command and exits with the mapped code on error.

Types

This section is empty.

Directories

Path Synopsis
Package auth implements `mp2rss auth ...` subcommands.
Package auth implements `mp2rss auth ...` subcommands.
Package mp implements `mp2rss mp ...` subcommands.
Package mp implements `mp2rss mp ...` subcommands.
Package skills implements the `mp2rss skills` command group: sync the repo's Agent Skills to the local agent config, show sync status, and list the official skills.
Package skills implements the `mp2rss skills` command group: sync the repo's Agent Skills to the local agent config, show sync status, and list the official skills.
Package update implements `mp2rss update` self-updating the installed binary.
Package update implements `mp2rss update` self-updating the installed binary.
x
Package x implements `mp2rss x ...` subcommands for X (Twitter) sources.
Package x implements `mp2rss x ...` subcommands for X (Twitter) sources.

Jump to