cmd

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

Package cmd wires the cobra command tree for mp2rss CLI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute runs the root command and exits with the mapped code on error.

Types

This section is empty.

Directories

Path Synopsis
Package auth implements `mp2rss auth ...` subcommands.
Package auth implements `mp2rss auth ...` subcommands.
Package mp implements `mp2rss mp ...` subcommands.
Package mp implements `mp2rss mp ...` subcommands.
Package update implements `mp2rss update` self-updating the installed binary.
Package update implements `mp2rss update` self-updating the installed binary.

Jump to